#####
#
# Import SIMO Results (SQLite-Databases) in R environment 
# and save a dataframe in folder /output
# CB
# 2019-07-12
#
#####



## load libraries
library(RSQLite)
library(tidyr)
library(dplyr)



# Variant 1: create a single dataframe for each SQL Database (selected columns of table UNIT)
# Dataframes are given the names of the DB and column "test" is added with the name of the DB

for (name in db_names){
  
  db <- dbConnect(dbDriver("SQLite"), dbname = paste0(path,"input_data/simulated_", sim_variant, "_", name, "_rsu.db"))
  rsl  <- dbGetQuery( db, paste0("select ", columns, " from UNIT"))
  rsl$gpkg <- name
  dbDisconnect(db)
  
  rsl <- rsl %>% 
    left_join(regime, by = "branching_group", all.x = TRUE)
  
  ### Filter those stands that caused errors during the simulation with SIMO
  # import csv file that contains the error stands
  error_stands <- read.csv(paste0(path, "params/errors_watersheds.csv"), sep = ",", header = TRUE, stringsAsFactors = FALSE)
  error_stands$id <- as.character(error_stands$id)

  rsl <- rsl %>%
    anti_join(error_stands, by = c("id", "gpkg"))
  
  write.table(rsl, paste0(path, "output/rsl_",sim_variant,"_",name,".csv" ), sep = ";", row.names = F, col.names = TRUE)
  
  assign( paste("rsl", name, sep="_"), rsl)
  rm(db, rsl)
  
}


# Variant 2: create one hughe dataframe combining all SQL databases (selected columns of table UNIT)
# Different DBs are indicated by an additional column "test"

rslt <- NULL

for (name in db_names){
  db <- dbConnect(dbDriver("SQLite"), dbname = paste0(path,"input_data/simulated_", sim_variant, "_" , name, "_rsu.db"))
  rsl  <- dbGetQuery( db, paste0("select ", columns, " from UNIT"))
  rsl$gpkg <- name
  dbDisconnect(db)
  rslt <- rbind(rslt, rsl)
  rm(db, rsl) 
}  

rslt <- rslt %>% 
  left_join(regime, by= "branching_group", all.X = TRUE)


### Filter those stands that caused errors during the simulation with SIMO
# import csv file that contains the error stands
error_stands <- read.csv(paste0(path, "params/errors_watersheds.csv"), sep = ",", header = TRUE, stringsAsFactors = FALSE)
error_stands$id <- as.character(error_stands$id)

rslt <- rslt %>%
  anti_join(error_stands, by = c("id", "gpkg"))

### write table
write.table(rslt, paste0(path, "output/rslt_", sim_variant, "_all.csv" ), sep = ";", row.names = F, col.names = TRUE)








# ##### Getting all Colnames from a SQL querry
# 
# # was used to create List of SIMO output -> What indicators can be calculate for ES
#  
# db <- dbConnect(dbDriver("SQLite"), dbname = paste0(path,"input_data/JENNI.db"))
# rsl  <- dbGetQuery(db, 'select * from UNIT')
# dbDisconnect(db)
# 
# colnames_FBE <- colnames(rsl) 
# noquote(colnames_FBE)
# write.table(colnames_FBE, paste0(path,"temp/colnames_FBE.csv"), row.names = FALSE)

